@@ -4,7 +4,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use JSON::Validator::OpenAPI;
 use constant DEBUG => $ENV{MOJO_OPENAPI_DEBUG} || 0;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub EXCEPTION { +{errors => [{message => 'Internal server error.', path => '/'}], status => 500} }
 sub NOT_FOUND { +{errors => [{message => 'Not found.',             path => '/'}], status => 404} }
@@ -33,9 +33,11 @@ sub register {
 
 sub _add_routes {
   my ($self, $app, $api_spec, $config) = @_;
-  my $base_path = $api_spec->get('/basePath') || '/';
-  my $paths     = $api_spec->get('/paths');
-  my $route     = $config->{route};
+  my $base_path    = $api_spec->get('/basePath') || '/';
+  my $paths        = $api_spec->get('/paths');
+  my $route        = $config->{route};
+  my $route_prefix = "";
+  my %uniq;
 
   $route = $route->any($base_path) if $route and !$route->pattern->unparsed;
   $route = $app->routes->any($base_path) unless $route;
@@ -48,6 +50,7 @@ sub _add_routes {
   my $spec_route = $route->get->to(cb => \&_reply_spec);
   if (my $spec_route_name = $config->{spec_route_name} || $api_spec->get('/x-mojo-name')) {
     $spec_route->name($spec_route_name);
+    $route_prefix = "$spec_route_name.";
   }
 
   for my $path (sort { length $a <=> length $b } keys %$paths) {
@@ -60,12 +63,16 @@ sub _add_routes {
       my $to      = $op_spec->{'x-mojo-to'};
       my $endpoint;
 
+      die qq([OpenAPI] operationId "$op_spec->{operationId}" is not unique)
+        if $op_spec->{operationId} and $uniq{o}{$op_spec->{operationId}}++;
+      die qq([OpenAPI] Route name "$name" is not unique.) if $name and $uniq{r}{$name}++;
+
       if ($name and $endpoint = $route->root->find($name)) {
         $route->add_child($endpoint);
       }
       if (!$endpoint) {
         $endpoint = $route->$http_method(_route_path($path, $op_spec));
-        $endpoint->name($name) if $name;
+        $endpoint->name("$route_prefix$name") if $name;
       }
 
       $endpoint->to(ref $to eq 'ARRAY' ? @$to : $to) if $to;
@@ -111,7 +118,7 @@ sub _load_spec {
   my $api_spec = $jv->schema($config->{url})->schema;
   my @errors
     = $jv->schema(JSON::Validator::OpenAPI::SPECIFICATION_URL())->validate($api_spec->data);
-  die join "\n", "Invalid Open API spec:", @errors if @errors;
+  die join "\n", "[OpenAPI] Invalid spec:", @errors if @errors;
   warn "[OpenAPI] Loaded $config->{url}\n" if DEBUG;
   return $api_spec;
 }
